# FireX Blaze

FireX Blaze is a lighweight process that receives data from Celery and puts it on a Kafka bus.


Briefy, FireX is a general-purpose automation platform that affords task definition and execution 
by writing lightly annotated Python code. 
